# SwaggerClient

Take screenshots of any website in real time

This ObjC package is automatically generated by the [Swagger Codegen](https://github.com/swagger-api/swagger-codegen) project:

- API version: 1.16.0
- Package version: 
- Build package: io.swagger.codegen.languages.ObjcClientCodegen
For more information, please visit [https://browshot.com/contact](https://browshot.com/contact)

## Requirements

The SDK requires [**ARC (Automatic Reference Counting)**](http://stackoverflow.com/questions/7778356/how-to-enable-disable-automatic-reference-counting) to be enabled in the Xcode project.

## Installation & Usage
### Install from Github using [CocoaPods](https://cocoapods.org/)

Add the following to the Podfile:

```ruby
pod 'SwaggerClient', :git => 'https://github.com//.git'
```

To specify a particular branch, append `, :branch => 'branch-name-here'`

To specify a particular commit, append `, :commit => '11aa22'`

### Install from local path using [CocoaPods](https://cocoapods.org/)

Put the SDK under your project folder (e.g. /path/to/objc_project/Vendor/SwaggerClient) and then add the following to the Podfile:

```ruby
pod 'SwaggerClient', :path => 'Vendor/SwaggerClient'
```

### Usage

Import the following:

```objc
#import <SwaggerClient/SWGApiClient.h>
#import <SwaggerClient/SWGConfiguration.h>
// load models
#import <SwaggerClient/SWGAccount.h>
#import <SwaggerClient/SWGAccountError.h>
#import <SwaggerClient/SWGBatch.h>
#import <SwaggerClient/SWGBatchError.h>
#import <SwaggerClient/SWGBrowser.h>
#import <SwaggerClient/SWGBrowserError.h>
#import <SwaggerClient/SWGBrowserList.h>
#import <SwaggerClient/SWGInstance.h>
#import <SwaggerClient/SWGInstanceError.h>
#import <SwaggerClient/SWGInstanceList.h>
#import <SwaggerClient/SWGScreenshot.h>
#import <SwaggerClient/SWGScreenshotError.h>
#import <SwaggerClient/SWGScreenshotHost.h>
#import <SwaggerClient/SWGScreenshotInfoError.h>
#import <SwaggerClient/SWGScreenshotList.h>
#import <SwaggerClient/SWGScreenshotShort.h>
// load API classes for accessing endpoints
#import <SwaggerClient/SWGAccountApi.h>
#import <SwaggerClient/SWGBatchApi.h>
#import <SwaggerClient/SWGBrowserApi.h>
#import <SwaggerClient/SWGInstanceApi.h>
#import <SwaggerClient/SWGScreenshotApi.h>

```

## Recommendation

It's recommended to create an instance of ApiClient per thread in a multi-threaded environment to avoid any potential issues.

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```objc

SWGConfiguration *apiConfig = [SWGConfiguration sharedConfig];

// Configure API key authorization: (authentication scheme: apiKeyQuery)
[apiConfig setApiKey:@"YOUR_API_KEY" forApiKeyIdentifier:@"key"];
// Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//[apiConfig setApiKeyPrefix:@"Bearer" forApiKeyIdentifier:@"key"];


NSNumber* *details = @1; // level of information returned (optional) (default to 1)

SWGAccountApi *apiInstance = [[SWGAccountApi alloc] init];

// Get information about your account.
[apiInstance accountInfoGetWithDetails:details
              completionHandler: ^(SWGAccount* output, NSError* error) {
                            if (output) {
                                NSLog(@"%@", output);
                            }
                            if (error) {
                                NSLog(@"Error: %@", error);
                            }
                        }];

```

## Documentation for API Endpoints

All URIs are relative to *https://api.browshot.com/api/v1*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*SWGAccountApi* | [**accountInfoGet**](docs/SWGAccountApi.md#accountinfoget) | **GET** /account/info | Get information about your account.
*SWGBatchApi* | [**batchCeatePost**](docs/SWGBatchApi.md#batchceatepost) | **POST** /batch/ceate | Requests thousands of screenshtos at once
*SWGBatchApi* | [**batchInfoGet**](docs/SWGBatchApi.md#batchinfoget) | **GET** /batch/info | Get the batch status
*SWGBrowserApi* | [**browserInfoGet**](docs/SWGBrowserApi.md#browserinfoget) | **GET** /browser/info | Get information about a browser
*SWGBrowserApi* | [**browserListGet**](docs/SWGBrowserApi.md#browserlistget) | **GET** /browser/list | Get all browsers
*SWGInstanceApi* | [**instanceInfoGet**](docs/SWGInstanceApi.md#instanceinfoget) | **GET** /instance/info | Get information about an instance
*SWGInstanceApi* | [**instanceListGet**](docs/SWGInstanceApi.md#instancelistget) | **GET** /instance/list | Get all instances
*SWGScreenshotApi* | [**screenshotCreateGet**](docs/SWGScreenshotApi.md#screenshotcreateget) | **GET** /screenshot/create | Request a screenshot
*SWGScreenshotApi* | [**screenshotDeleteGet**](docs/SWGScreenshotApi.md#screenshotdeleteget) | **GET** /screenshot/delete | Delete screenshot data
*SWGScreenshotApi* | [**screenshotHostGet**](docs/SWGScreenshotApi.md#screenshothostget) | **GET** /screenshot/host | Host thumbnails on your own S3 account or on Browshot.
*SWGScreenshotApi* | [**screenshotHtmlGet**](docs/SWGScreenshotApi.md#screenshothtmlget) | **GET** /screenshot/html | Get the HTML code
*SWGScreenshotApi* | [**screenshotInfoGet**](docs/SWGScreenshotApi.md#screenshotinfoget) | **GET** /screenshot/info | Query screenshot status
*SWGScreenshotApi* | [**screenshotListGet**](docs/SWGScreenshotApi.md#screenshotlistget) | **GET** /screenshot/list | Get information about the last 100 screenshots requested.
*SWGScreenshotApi* | [**screenshotMultipleGet**](docs/SWGScreenshotApi.md#screenshotmultipleget) | **GET** /screenshot/multiple | Request multiple screenshots
*SWGScreenshotApi* | [**screenshotSearchGet**](docs/SWGScreenshotApi.md#screenshotsearchget) | **GET** /screenshot/search | Search for screenshots of a specific URL.
*SWGScreenshotApi* | [**screenshotShareGet**](docs/SWGScreenshotApi.md#screenshotshareget) | **GET** /screenshot/share | Share a screenshot
*SWGScreenshotApi* | [**screenshotThumbnailGet**](docs/SWGScreenshotApi.md#screenshotthumbnailget) | **GET** /screenshot/thumbnail | Retrieve a thumbnail image


## Documentation For Models

 - [SWGAccount](docs/SWGAccount.md)
 - [SWGAccountError](docs/SWGAccountError.md)
 - [SWGBatch](docs/SWGBatch.md)
 - [SWGBatchError](docs/SWGBatchError.md)
 - [SWGBrowser](docs/SWGBrowser.md)
 - [SWGBrowserError](docs/SWGBrowserError.md)
 - [SWGBrowserList](docs/SWGBrowserList.md)
 - [SWGInstance](docs/SWGInstance.md)
 - [SWGInstanceError](docs/SWGInstanceError.md)
 - [SWGInstanceList](docs/SWGInstanceList.md)
 - [SWGScreenshot](docs/SWGScreenshot.md)
 - [SWGScreenshotError](docs/SWGScreenshotError.md)
 - [SWGScreenshotHost](docs/SWGScreenshotHost.md)
 - [SWGScreenshotInfoError](docs/SWGScreenshotInfoError.md)
 - [SWGScreenshotList](docs/SWGScreenshotList.md)
 - [SWGScreenshotShort](docs/SWGScreenshotShort.md)


## Documentation For Authorization


## apiKeyQuery

- **Type**: API key
- **API key parameter name**: key
- **Location**: URL query string


## Author

support@browshot.com


