#import "SWGBatchApi.h"
#import "SWGQueryParamCollection.h"
#import "SWGBatch.h"
#import "SWGBatchError.h"


@interface SWGBatchApi ()

@property (nonatomic, strong) NSMutableDictionary *defaultHeaders;

@end

@implementation SWGBatchApi

NSString* kSWGBatchApiErrorDomain = @"SWGBatchApiErrorDomain";
NSInteger kSWGBatchApiMissingParamErrorCode = 234513;

@synthesize apiClient = _apiClient;

#pragma mark - Initialize methods

- (instancetype) init {
    self = [super init];
    if (self) {
        SWGConfiguration *config = [SWGConfiguration sharedConfig];
        if (config.apiClient == nil) {
            config.apiClient = [[SWGApiClient alloc] init];
        }
        _apiClient = config.apiClient;
        _defaultHeaders = [NSMutableDictionary dictionary];
    }
    return self;
}

- (id) initWithApiClient:(SWGApiClient *)apiClient {
    self = [super init];
    if (self) {
        _apiClient = apiClient;
        _defaultHeaders = [NSMutableDictionary dictionary];
    }
    return self;
}

#pragma mark -

+ (instancetype)sharedAPI {
    static SWGBatchApi *sharedAPI;
    static dispatch_once_t once;
    dispatch_once(&once, ^{
        sharedAPI = [[self alloc] init];
    });
    return sharedAPI;
}

-(NSString*) defaultHeaderForKey:(NSString*)key {
    return self.defaultHeaders[key];
}

-(void) addHeader:(NSString*)value forKey:(NSString*)key {
    [self setDefaultHeaderValue:value forKey:key];
}

-(void) setDefaultHeaderValue:(NSString*) value forKey:(NSString*)key {
    [self.defaultHeaders setValue:value forKey:key];
}

-(NSUInteger) requestQueueSize {
    return [SWGApiClient requestQueueSize];
}

#pragma mark - Api Methods

///
/// Requests thousands of screenshtos at once
/// Get hundreds or thousands of screenshots from a text file. You can use this API call or the dashboard. Unlike the other API calls, you must issue a POST request with the Content-Type \"multipart/form-data\" in order to upload the text file. The text file must contain the list of URLs to request, 1 URL per line. Failed screenshots will be tried up to 3 times before giving up. 
/// @param instanceId instance ID to use 
///
/// @param file text file to use (optional)
///
/// @param size screenshots size - \"screen\" (default) or \"page\" (optional, default to screen)
///
/// @param name name of the batch (optional)
///
/// @param width thumbnail width. (optional, default to 1024)
///
/// @param height thumbnail height (optional)
///
/// @param delay number of seconds to wait after the page has loaded. This is used to let JavaScript run longer before taking the screenshot. Use delay=0 to take screenshots faster. (optional, default to 5)
///
/// @param flashDelay number of seconds to wait after the page has loaded if Flash elements are present. Use flash_delay=0 to take screenshots faster. (optional, default to 10)
///
/// @param screenWidth width of the browser window. For desktop browsers only. (optional, default to 1024)
///
/// @param screenHeight height of the browser window. For desktop browsers only. (Note: full-page screenshots can have a height of up to 15,000px) (optional, default to 768)
///
/// @param priority assign priority to the screenshot (for private instances only) (optional)
///
/// @param referer use a custom referrer header - paid screenshots only (optional)
///
/// @param postData send a POST requests with post_data, useful for filling out forms - paid screenshots only (optional)
///
/// @param cookie set a cookie for the URL requested (see Custom POST Data, Referer and Cookie) Cookies should be separated by a ; - paid screenshots only (optional)
///
/// @param script URL of javascript file to execute after the page load event (optional)
///
/// @param details level of information available with screenshot/info (optional, default to 2)
///
/// @param html saves the HTML of the rendered page which can be retrieved by the API call screenshot/html. This feature costs *1 credit* per screenshot. (optional, default to 0)
///
/// @param maxWait maximum number of seconds to wait before triggering the PageLoad event. Note that delay will still be used. (default: 0 = disabled) (optional, default to 0)
///
/// @param headers any custom HTTP headers. (Not supported with Internet Explorer) (optional)
///
/// @param format image as PNG or JPEG (optional, default to png)
///
/// @param shots take multiple screenshots of the same page. This costs 1 additional credit for every 2 additional screenshots. (optional, default to 1)
///
/// @param shotInterval number of seconds between 2 screenshots (optional, default to 5)
///
///  code:200 message:"batch information",
///  code:0 message:"Batch not created"
/// @return NSArray<SWGBatch>*
-(NSNumber*) batchCeatePostWithInstanceId: (NSNumber*) instanceId
    file: (NSURL*) file
    size: (NSString*) size
    name: (NSString*) name
    width: (NSNumber*) width
    height: (NSNumber*) height
    delay: (NSNumber*) delay
    flashDelay: (NSNumber*) flashDelay
    screenWidth: (NSNumber*) screenWidth
    screenHeight: (NSNumber*) screenHeight
    priority: (NSNumber*) priority
    referer: (NSString*) referer
    postData: (NSString*) postData
    cookie: (NSString*) cookie
    script: (NSString*) script
    details: (NSNumber*) details
    html: (NSNumber*) html
    maxWait: (NSNumber*) maxWait
    headers: (NSString*) headers
    format: (NSString*) format
    shots: (NSNumber*) shots
    shotInterval: (NSNumber*) shotInterval
    completionHandler: (void (^)(NSArray<SWGBatch>* output, NSError* error)) handler {
    // verify the required parameter 'instanceId' is set
    if (instanceId == nil) {
        NSParameterAssert(instanceId);
        if(handler) {
            NSDictionary * userInfo = @{NSLocalizedDescriptionKey : [NSString stringWithFormat:NSLocalizedString(@"Missing required parameter '%@'", nil),@"instanceId"] };
            NSError* error = [NSError errorWithDomain:kSWGBatchApiErrorDomain code:kSWGBatchApiMissingParamErrorCode userInfo:userInfo];
            handler(nil, error);
        }
        return nil;
    }

    NSMutableString* resourcePath = [NSMutableString stringWithFormat:@"/batch/ceate"];

    // remove format in URL if needed
    [resourcePath replaceOccurrencesOfString:@".{format}" withString:@".json" options:0 range:NSMakeRange(0,resourcePath.length)];

    NSMutableDictionary *pathParams = [[NSMutableDictionary alloc] init];

    NSMutableDictionary* queryParams = [[NSMutableDictionary alloc] init];
    NSMutableDictionary* headerParams = [NSMutableDictionary dictionaryWithDictionary:self.apiClient.configuration.defaultHeaders];
    [headerParams addEntriesFromDictionary:self.defaultHeaders];
    // HTTP header `Accept`
    NSString *acceptHeader = [self.apiClient.sanitizer selectHeaderAccept:@[@"application/json"]];
    if(acceptHeader.length > 0) {
        headerParams[@"Accept"] = acceptHeader;
    }

    // response content type
    NSString *responseContentType = [[acceptHeader componentsSeparatedByString:@", "] firstObject] ?: @"";

    // request content type
    NSString *requestContentType = [self.apiClient.sanitizer selectHeaderContentType:@[@"multipart/form-data"]];

    // Authentication setting
    NSArray *authSettings = @[@"apiKeyQuery"];

    id bodyParam = nil;
    NSMutableDictionary *formParams = [[NSMutableDictionary alloc] init];
    NSMutableDictionary *localVarFiles = [[NSMutableDictionary alloc] init];
    if (instanceId) {
        formParams[@"instance_id"] = instanceId;
    }
    localVarFiles[@"file"] = file;
    if (size) {
        formParams[@"size"] = size;
    }
    if (name) {
        formParams[@"name"] = name;
    }
    if (width) {
        formParams[@"width"] = width;
    }
    if (height) {
        formParams[@"height"] = height;
    }
    if (delay) {
        formParams[@"delay"] = delay;
    }
    if (flashDelay) {
        formParams[@"flash_delay"] = flashDelay;
    }
    if (screenWidth) {
        formParams[@"screen_width"] = screenWidth;
    }
    if (screenHeight) {
        formParams[@"screen_height"] = screenHeight;
    }
    if (priority) {
        formParams[@"priority"] = priority;
    }
    if (referer) {
        formParams[@"referer"] = referer;
    }
    if (postData) {
        formParams[@"post_data"] = postData;
    }
    if (cookie) {
        formParams[@"cookie"] = cookie;
    }
    if (script) {
        formParams[@"script"] = script;
    }
    if (details) {
        formParams[@"details"] = details;
    }
    if (html) {
        formParams[@"html"] = html;
    }
    if (maxWait) {
        formParams[@"max_wait"] = maxWait;
    }
    if (headers) {
        formParams[@"headers"] = headers;
    }
    if (format) {
        formParams[@"format"] = format;
    }
    if (shots) {
        formParams[@"shots"] = shots;
    }
    if (shotInterval) {
        formParams[@"shot_interval"] = shotInterval;
    }

    return [self.apiClient requestWithPath: resourcePath
                                    method: @"POST"
                                pathParams: pathParams
                               queryParams: queryParams
                                formParams: formParams
                                     files: localVarFiles
                                      body: bodyParam
                              headerParams: headerParams
                              authSettings: authSettings
                        requestContentType: requestContentType
                       responseContentType: responseContentType
                              responseType: @"NSArray<SWGBatch>*"
                           completionBlock: ^(id data, NSError *error) {
                                if(handler) {
                                    handler((NSArray<SWGBatch>*)data, error);
                                }
                           }
          ];
}

///
/// Get the batch status
/// Get the status of a batch requested through the API or through the dashboard. 
/// @param _id batch ID 
///
///  code:200 message:"batch information",
///  code:0 message:"Batch not found"
/// @return SWGBatch*
-(NSNumber*) batchInfoGetWithId: (NSNumber*) _id
    completionHandler: (void (^)(SWGBatch* output, NSError* error)) handler {
    // verify the required parameter '_id' is set
    if (_id == nil) {
        NSParameterAssert(_id);
        if(handler) {
            NSDictionary * userInfo = @{NSLocalizedDescriptionKey : [NSString stringWithFormat:NSLocalizedString(@"Missing required parameter '%@'", nil),@"_id"] };
            NSError* error = [NSError errorWithDomain:kSWGBatchApiErrorDomain code:kSWGBatchApiMissingParamErrorCode userInfo:userInfo];
            handler(nil, error);
        }
        return nil;
    }

    NSMutableString* resourcePath = [NSMutableString stringWithFormat:@"/batch/info"];

    // remove format in URL if needed
    [resourcePath replaceOccurrencesOfString:@".{format}" withString:@".json" options:0 range:NSMakeRange(0,resourcePath.length)];

    NSMutableDictionary *pathParams = [[NSMutableDictionary alloc] init];

    NSMutableDictionary* queryParams = [[NSMutableDictionary alloc] init];
    if (_id != nil) {
        queryParams[@"id"] = _id;
    }
    NSMutableDictionary* headerParams = [NSMutableDictionary dictionaryWithDictionary:self.apiClient.configuration.defaultHeaders];
    [headerParams addEntriesFromDictionary:self.defaultHeaders];
    // HTTP header `Accept`
    NSString *acceptHeader = [self.apiClient.sanitizer selectHeaderAccept:@[@"application/json"]];
    if(acceptHeader.length > 0) {
        headerParams[@"Accept"] = acceptHeader;
    }

    // response content type
    NSString *responseContentType = [[acceptHeader componentsSeparatedByString:@", "] firstObject] ?: @"";

    // request content type
    NSString *requestContentType = [self.apiClient.sanitizer selectHeaderContentType:@[]];

    // Authentication setting
    NSArray *authSettings = @[@"apiKeyQuery"];

    id bodyParam = nil;
    NSMutableDictionary *formParams = [[NSMutableDictionary alloc] init];
    NSMutableDictionary *localVarFiles = [[NSMutableDictionary alloc] init];

    return [self.apiClient requestWithPath: resourcePath
                                    method: @"GET"
                                pathParams: pathParams
                               queryParams: queryParams
                                formParams: formParams
                                     files: localVarFiles
                                      body: bodyParam
                              headerParams: headerParams
                              authSettings: authSettings
                        requestContentType: requestContentType
                       responseContentType: responseContentType
                              responseType: @"SWGBatch*"
                           completionBlock: ^(id data, NSError *error) {
                                if(handler) {
                                    handler((SWGBatch*)data, error);
                                }
                           }
          ];
}


@end
